##  Synchronized Attributes
During periodic synchronizations, the following user details are updated:
  * First name
  * Last name
  * Email address
  * Username
  * Role, custom roles, and Access Control Entities (ACEs), if applicable
  * Department, if applicable
